@@ -134,8 +134,9 @@ class ElasticClient(object):
         Return the object mappings currently used by ES.
         """
         doc_type = cls and cls.__name__
-        return self.es.indices.get_mapping(index=self.index,
-                                           doc_type=doc_type)
+        raw = self.es.indices.get_mapping(index=self.index,
+                                          doc_type=doc_type)
+        return raw[self.index]['mappings']
 
     def index_object(self, obj):
         """
@@ -157,6 +158,21 @@ class ElasticClient(object):
                             doc=doc,
                             parent=doc_parent)
 
+    def delete_object(self, obj, safe=False):
+        """
+        Delete the indexed document for an object.
+        """
+        doc = obj.elastic_document()
+
+        doc_type = obj.__class__.__name__
+        doc_id = doc.pop("_id")
+        doc_parent = obj.elastic_parent
+
+        self.delete_document(id=doc_id,
+                             doc_type=doc_type,
+                             parent=doc_parent,
+                             safe=safe)
+
     def index_document(self, id, doc_type, doc, parent=None):
         """
         Add or update the indexed document from a raw document source (not an
@@ -173,6 +189,25 @@ class ElasticClient(object):
             kwargs['parent'] = parent
         self.es.index(**kwargs)
 
+    def delete_document(self, id, doc_type, parent=None, safe=False):
+        """
+        Delete the indexed document based on a raw document source (not an
+        object).
+        """
+        if self.disable_indexing:
+            return
+
+        kwargs = dict(index=self.index,
+                      doc_type=doc_type,
+                      id=id)
+        if parent:
+            kwargs['routing'] = parent
+        try:
+            self.es.delete(**kwargs)
+        except NotFoundError:
+            if not safe:
+                raise
+
     def index_objects(self, objects):
         """
         Add multiple objects to the index.
